==> khroma_1.6.0.tar.gz: khroma/tests/testthat/_snaps/colour.md <==
# Palette informations

    Code
      info()
    Output
                  palette        type max missing
      1              broc   diverging 256    <NA>
      2              cork   diverging 256    <NA>
      3               vik   diverging 256    <NA>
      4            lisbon   diverging 256    <NA>
      5            tofino   diverging 256    <NA>
      6            berlin   diverging 256    <NA>
      7              roma   diverging 256    <NA>
      8               bam   diverging 256    <NA>
      9            vanimo   diverging 256    <NA>
      10           oleron   diverging 256    <NA>
      11           bukavu   diverging 256    <NA>
      12              fes   diverging 256    <NA>
      13            devon  sequential 256    <NA>
      14          lajolla  sequential 256    <NA>
      15           bamako  sequential 256    <NA>
      16            davos  sequential 256    <NA>
      17           bilbao  sequential 256    <NA>
      18             nuuk  sequential 256    <NA>
      19             oslo  sequential 256    <NA>
      20            grayC  sequential 256    <NA>
      21           hawaii  sequential 256    <NA>
      22            lapaz  sequential 256    <NA>
      23            tokyo  sequential 256    <NA>
      24             buda  sequential 256    <NA>
      25            acton  sequential 256    <NA>
      26            turku  sequential 256    <NA>
      27            imola  sequential 256    <NA>
      28           batlow  sequential 256    <NA>
      29          batlowW  sequential 256    <NA>
      30          batlowK  sequential 256    <NA>
      31            brocO  sequential 256    <NA>
      32            corkO  sequential 256    <NA>
      33             vikO  sequential 256    <NA>
      34            romaO  sequential 256    <NA>
      35             bamO  sequential 256    <NA>
      36           bright qualitative   7    <NA>
      37         contrast qualitative   3    <NA>
      38          vibrant qualitative   7    <NA>
      39            muted qualitative   9 #DDDDDD
      40             pale qualitative   6    <NA>
      41             dark qualitative   6    <NA>
      42            light qualitative   9    <NA>
      43           sunset   diverging  11 #FFFFFF
      44             BuRd   diverging   9 #FFEE99
      45             PRGn   diverging   9 #FFEE99
      46           YlOrBr  sequential   9 #888888
      47       iridescent  sequential  23 #999999
      48 discrete rainbow  sequential  23 #777777
      49   smooth rainbow  sequential  34 #666666
      50        okabe ito qualitative   8    <NA>
      51     stratigraphy qualitative 175    <NA>
      52             soil qualitative  24    <NA>
      53             land qualitative  14    <NA>

==> khroma_1.7.0.tar.gz: khroma/tests/testthat/_snaps/colour.md <==
# Palette informations

    Code
      info()
    Output
                  palette        type max missing
      1              broc   diverging 256    <NA>
      2              cork   diverging 256    <NA>
      3               vik   diverging 256    <NA>
      4            lisbon   diverging 256    <NA>
      5            tofino   diverging 256    <NA>
      6            berlin   diverging 256    <NA>
      7              roma   diverging 256    <NA>
      8               bam   diverging 256    <NA>
      9            vanimo   diverging 256    <NA>
      10           oleron   diverging 256    <NA>
      11           bukavu   diverging 256    <NA>
      12              fes   diverging 256    <NA>
      13            devon  sequential 256    <NA>
      14          lajolla  sequential 256    <NA>
      15           bamako  sequential 256    <NA>
      16            davos  sequential 256    <NA>
      17           bilbao  sequential 256    <NA>
      18             nuuk  sequential 256    <NA>
      19             oslo  sequential 256    <NA>
      20            grayC  sequential 256    <NA>
      21           hawaii  sequential 256    <NA>
      22            lapaz  sequential 256    <NA>
      23            tokyo  sequential 256    <NA>
      24             buda  sequential 256    <NA>
      25            acton  sequential 256    <NA>
      26            turku  sequential 256    <NA>
      27            imola  sequential 256    <NA>
      28           batlow  sequential 256    <NA>
      29          batlowW  sequential 256    <NA>
      30          batlowK  sequential 256    <NA>
      31            brocO  sequential 256    <NA>
      32            corkO  sequential 256    <NA>
      33             vikO  sequential 256    <NA>
      34            romaO  sequential 256    <NA>
      35             bamO  sequential 256    <NA>
      36           bright qualitative   7    <NA>
      37    high contrast qualitative   3    <NA>
      38          vibrant qualitative   7    <NA>
      39            muted qualitative   9 #DDDDDD
      40  medium contrast qualitative   6    <NA>
      41             pale qualitative   6    <NA>
      42             dark qualitative   6    <NA>
      43            light qualitative   9    <NA>
      44           sunset   diverging  11 #FFFFFF
      45             BuRd   diverging   9 #FFEE99
      46             PRGn   diverging   9 #FFEE99
      47           YlOrBr  sequential   9 #888888
      48       iridescent  sequential  23 #999999
      49 discrete rainbow  sequential  23 #777777
      50   smooth rainbow  sequential  34 #666666
      51        okabe ito qualitative   8    <NA>
      52     stratigraphy qualitative 175    <NA>
      53             soil qualitative  24    <NA>
      54             land qualitative  14    <NA>
